function sdot=f_Stop(t,x,...
                                N, m,...
                                CD0clean,CDflaps,CDgear,CDsp,CDspoiler,Sspoiler,...
                                CL0clean,CLflaps,CLalpha,...
                                Sw,h,b,k_TO,...
                                mu,muB,rho,...
                                alpha,gamma,...
                                F0,di,Tidle,BPR,...
                                vW,vREL,vEF,...
                                fL, ...
                                deltaT,H,....
                    lE,lv,Sv,Sr,Av,sweepV)
  
%   t => independent variable 
%   x => dependent
%        n*2 vector (y / y')

%   y'' = v' =  a
%   y'  = v
%   y   =       s


% inflow velocity v=vG+vW
% vG=S(2) ground roll speed (regarding runway) [m/s]
s  = x(1); 
vG = x(2); % vG = x'
v  = vG + vW;

... delta_CDflap. Cd_asy,... included via CD0

% muB ...
     ...concrete                    => 0.3-0.6
     ...hard turf                   => 0.4
     ...film & dry dirt             => 0.3-0.6
     ...soft turf                   => 0.5     
     ...wet & concrete              => 0.2
     ...wet grass                   => 0.2
     ...snow or ice coverd field    => 0.07-0.1

%vREL	0.12 		primary airflow of high bypass engines
...		0.25 		for straight turbojet & turboprop engines
...		0.42 		low bypass ratio engines, mixed flow
...		0.92 		fan airflow of high bypass engines

N = N-1; % number of operating engines

g   = 9.80665; %m/s^2
W   = m*g; % weight force
AR  = b^2/Sw; % aspect ratio

% k       = 1/(pi*e*AR)
% k_TO    = 1/(1/k+pi*AR*delta_e)

alphaRad = alpha*pi/180; 
gammaRad = gamma*pi/180; 

%standard
% k1 = 2.44 * 10^(-4) * BPR  +  1.66 * 10^(-3);
% k2 = 6.16 * 10^(-7) * BPR  +  4.08 * 10^(-6);
%F1    = N*F0*( 1 - k1*v + k2*v^2); %Scholz / Young / Roskam / ...

... constants:
p0    = 101325;
R     = 287.058;
L     = 0.0065;
T0    = 288.15 + deltaT;
kappa = 1.4;

% Young 2008
p     = p0*(1-H*L/T0)^(g/(R*L)); % pressure
A     = -0.4327*(p/p0).^2+1.3855*(p/p0)+0.0472 ; %thrust factor
X     = 0.1377*(p/p0).^2-0.4374*(p/p0)+1.3003; %thrust factor
Z     = 0.9106*(p/p0).^2-1.7736*(p/p0)+1.8697; %thrust factor
T     = T0-0.0065*H; %temperature as a funcion of height
c     = sqrt(R*kappa*T); %speed of sound

... linear G-factor function: 
G     = 0.061*BPR + 0.633; % gas generator factor, Young 2008
... => A340, BPR = 7.6
... => A320, BPR = 6
... equation determined in excel with 2 values of the original diagram 
    
... thrust factors:
K1   =  (((0.377*(1+BPR))  /   sqrt((1+0.82*BPR)*G)))*Z * (p/p0);
K2   =  (0.23+0.19*sqrt(BPR)).*X.*p/p0 ;

...R    = 0; % reverse thrust, not allowed for BFL with dry runway

AN   =     pi/4*di^2; % area => inlet, engine
% M       = v/c; % mach number
% CDwm    = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw; %windmill drag:
phi     = (16*h/b)^2 / (1+(16*h/b)^2); %ground effect

qv = rho*0.5*v^2; % dynamic pressure

Fspoiler = rho/2* v^2 * CDspoiler* Sspoiler* sin(50*pi/180) ;


..._________________________________________________________________________________________________________________
if t >= 0 && t < 0.5 % 1st reaction => brakes => mu = muB (0.35)
   
    ...full braking effect develops linear within 2 seconds 

    M    = v/c;
    CDwm = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw; 

              dF    = (1*F0*( A - K1*(v/c) + K2*(v/c).^2)) + CDwm;

              Cyv = dF / (Sv*qv) *lE/lv;
              CDs = 2.3/pi *sqrt(Sr*Sv)*Av^(-4/3) *cos(sweepV*pi/180)^(1/3)*Cyv^2;
              CDasym = CDs / Sw; % rudder 

    CLg  = CL0clean + CLflaps + CLalpha*alphaRad + CLflaps; 
    CD0  = CD0clean + CDflaps + CDgear + CDwm + CDasym +CDsp;
    CD   = CD0 + phi*k_TO*CLg^2;
     F    = N*F0*( A - K1*(M)  +    K2*(M).^2) ;
        if t >= 0 && t < 0.1
        muBx = 0.1/2* muB;
        elseif t >= 0.1 && t < 0.2
        muBx = 0.2/2* muB;
        elseif t >= 0.2 && t < 0.3
        muBx = 0.3/2* muB;
        elseif t >= 0.3 && t < 0.4
        muBx = 0.4/2* muB;
        elseif t >= 0.4 && t < 0.5
        muBx = 0.5/2* muB;            
        end
    a    = -g*muBx *((fL*cos(gammaRad)+sin(gammaRad)/muBx -F/(W*muBx)) +rho/2*Sw/W*(CD/muBx -CLg )*v^2);
..._________________________________________________________________________________________________________________

elseif t >= 0.5 && t < 1   % 2nd reaction => Fo = idle thrust, 
...                                       =>  CDasym,idle => neglegted (insignificantly small)
    M    = v/c;
    CDwm = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw; 
    CLg  = CL0clean + CLflaps + CLalpha*alphaRad ;
    CD0  = CD0clean + CDflaps + CDgear + CDwm + CDsp;
    CD   = CD0 + phi*k_TO*CLg^2;
    F    = N*Tidle*( A - K1*(M)  +    K2*(M).^2) ;
        if t >= 0.5 && t < 0.6
        muBx = 0.6/2* muB;
        elseif t >= 0.6 && t < 0.7
        muBx = 0.7/2* muB;
        elseif t >= 0.7 && t < 0.8
        muBx = 0.8/2* muB;
        elseif t >= 0.8 && t < 0.9
        muBx = 0.9/2* muB;
        elseif t >= 0.9 && t < 1
        muBx = 1/2* muB;           
        end
    a    = -g*muBx *((fL*cos(gammaRad)+sin(gammaRad)/muBx -F/(W*muBx)) +rho/2*Sw/W*(CD/muBx -CLg )*v^2); 

    ..._____________________________________________________________________________________________________

elseif t >= 1  % 3rd reaction => spoiler / flaps

        if t >= 1 && t < 1.1
        muBx = 1.1/2* muB;
        elseif t >= 1.1 && t < 1.2
        muBx = 1.2/2* muB;
        elseif t >= 1.2 && t < 1.3
        muBx = 1.3/2* muB;
        elseif t >= 1.3 && t < 1.4
        muBx = 1.4/2* muB;
        elseif t >= 1.4 && t < 1.5
        muBx = 1.5/2* muB;
        elseif t >= 1.5 && t < 1.6
        muBx = 1.6/2* muB;
        elseif t >= 1.6 && t < 1.7
        muBx = 1.7/2* muB;
        elseif t >= 1.7 && t < 1.8
        muBx = 1.8/2* muB;
        elseif t >= 1.8 && t < 1.9
        muBx = 1.9/2* muB;
        elseif t >= 1.9 
        muBx = 1* muB; 
        end

    M    = v/c;
    CDwm = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw;
    CLg  = CL0clean + CLflaps + CLalpha*alphaRad ;
    CD0  = CD0clean + CDflaps + CDgear + CDwm +CDsp;   
    CD   = CD0 + phi*k_TO*CLg^2;
    F    = N*Tidle*( A - K1*(M)  +    K2*(M).^2) ;

    ...spoiler condidered via parameter Fspoiler

    a    = -g*muBx *((Fspoiler/(W*muBx) + fL*cos(gammaRad)+sin(gammaRad)/muBx  -F/(W*muBx)) +rho/2*Sw/W*(CD/muBx -CLg )*v^2);
end

    ..._____________________________________________________________________________________________________

sdot(1,1) = vG;  % v = s' =  ds/dt
sdot(2,1) = a; % v' = s'' = a

return