% function [vEAS_kt,vTAS_kt,rho,p,T,qc,sigma,delta,theta] ...
%    = f_speedConvertion(vCAS_kt, ...
%                         dT, ...
%                         H_ft) 

function [vTAS_kt] = f_speedConvertion(vCAS_kt, dT, H_ft) 

g      = 9.80665; % [m/s^2]
R      = 287.058; % [J/(kg K)]
kappa  = 1.4;
L      = 6.5*10^-3; % [K/m]

... ISA values, MSL:  
p0        = 10325; % [Pa]
rho0      = 1.225; % [kg/m^3]
T0_ISA    = 288.15; % [K]
T0        = T0_ISA + dT ; % [°K]

...convert to metric units
H         = H_ft*0.3048;  % [m]
vCAS      = vCAS_kt*0.51444;% [m/s]

p    = p0   *(1-L*H/T0)^(g/(R*L));
rho  = rho0 *(1-L*H/T0)^(g/(R*L)-1);
T    = T0 - L*H;
a0   = sqrt(T0*R*kappa) ;
a    = sqrt(T*R*kappa) ;

sigma = rho/rho0;
delta = p/p0;
theta = T/T0;

qc = p0*(( ((kappa-1)/2 *(vCAS/a0)^2 + 1  )^(kappa/(kappa-1)) ) -1 );

vTAS  = a *sqrt( 2/(kappa-1) *( (qc/p+1)^((kappa-1)/kappa) -1) );

vEAS = a0 * sqrt( ...
                  5*delta*(( ...
                            1/delta*(( ...
                                      1+0.2*(vCAS/a0)^2 ...
                                     )^3.5-1 ...
                                    ) ...
                                    +1 ...
                            )^(1/3.5) ...
                                     -1 ...
                           )...
                );
            
% vTAS = vEAS / sqrt(sigma) ;

vEAS_kt = vEAS*1/0.51444;
vTAS_kt = vTAS*1/0.51444;

end